Chicken in curry sauce | bonty
Description: Easy to make recipe with chicken, curry sauce and rice
Keywords: Dinners,Recipes,Chicken,Curry

# Chicken in curry sauce

Easy to make recipe with chicken, curry sauce and rice
Written by Tomas Lyngen
Published: 19 Nov 2022

## Ingredients

- 4-6 pieces of chicken
- 1 tbps butter or oil for frying
- 100-200 g vegetables (optional), frozen works fine

### Sauce

- 6 dl milk or cream
- 2 dl ketchup
- 5 tsp curry
- 2 tbsp vinegar (optional)

### Sauce seasoning

- 3 tsp paprika
- 2 tsp salt
- 2 tsp pepper

### Served along

- 3-4 scope Rice

## Directions

### Fry chicken

Add some butter or oil in a pan, then fry the chicken lightly on both sides until golden. Chicken will be added to the sauce later, so no need to cook through

### Mix sauce

In a casserole, add the ingredients for the sauce and mix together

### Add seasoning

Now you add spices, here we recommend season to taste

### Add chicken and cook

Now add the chicken and cook on medium heat for about 10 minutes

### Add vegetables (optional)

We recommend adding vegetables, then cook for another 10-15 minutes

### Serve with rice

Now it's time to sit down and enjoy the meal

Tags: #Chicken #Curry
Share on Facebook Share on Twitter
We sometimes publish affiliate links and these always needs to follow our editorial policy, for more information check out our affiliate link policy

## You might also like

### Chicken Katsu

### Sausage Stroganoff

### Bistek (Filipino Beefsteak)

### Pytt i Panne with Sausage

### Layered nachos

### Norwegian Fish Gratin: Recipe

### Simple Wok recipe

### Norwegian pancakes: Recipe

### Getting tender spare ribs with Pressure Cooker: Recipe

### Comments

Sign up or Login to post a comment

There are no comments, be the first to comment.